@@ -103,6 +103,7 @@ public:
 
     int         checker_status(int user, long file, MediaConchLib::Checker_StatusRes& res, std::string& error);
     int         checker_clear(int user, const std::vector<long>& files, std::string& error);
+    int         checker_stop(int user, const std::vector<long>& files, std::string& error);
 
     int         checker_list(int user, std::vector<std::string>& vec, std::string& error);
     int         checker_list(int user, std::vector<long>& vec, std::string& error);
@@ -147,6 +148,7 @@ public:
     // Configuration
     //***************************************************************************
     void               load_configuration();
+    void               set_default_scheduler_max_threads(size_t nb);
     void               set_configuration_file(const std::string& file);
     const std::string& get_configuration_file() const;
     void               load_plugins_configuration();
