@@ -85,6 +85,9 @@ public:
     // Clear
     int checker_clear(int user, const std::vector<long>& files, std::string& error);
 
+    // Stop
+    int checker_stop(int user, const std::vector<long>& files, std::string& error);
+
     // Report
     int checker_get_report(CheckerReport& c_report, MediaConchLib::Checker_ReportRes* result, std::string& error);
     int checker_validate(int user, MediaConchLib::report report, const std::vector<long>& files,
