@@ -220,13 +220,13 @@ namespace MediaConch
 
     void WebCommonPage::on_file_selected(const QString& filename, const QString& path,
                                          const QString& policy, const QString& display,
-                                         const QString& verbosity, bool fixer,
+                                         const QString& verbosity, bool fixer, const QStringList& options,
                                          QString& ret, std::string& err_str)
     {
         std::string error;
         std::string full_file(path.toUtf8().data());
         if (mainwindow->add_file_to_list(filename, path, policy,
-                                         display, verbosity, fixer, false, error) < 0)
+                                         display, verbosity, fixer, false, options, error) < 0)
         {
             if (err_str.size())
                 err_str += "\n";
@@ -271,7 +271,7 @@ namespace MediaConch
 
         QString err;
         if (err_str.size())
-            err = QString("\"error\":%1").arg(QString().fromUtf8(err_str.c_str(), err_str.size()));
+            err = QString("\"error\":\"%1\"").arg(QString().fromUtf8(err_str.c_str(), err_str.size()));
 
         if (err.size())
         {
@@ -316,7 +316,7 @@ namespace MediaConch
     }
 
     QString WebCommonPage::on_file_upload_selected(const QString& policy, const QString& display,
-                                                   const QString& verbosity, bool fixer)
+                                                   const QString& verbosity, bool fixer, const QStringList& options)
     {
         QStringList files = file_selector.value("checkerUpload_file", QStringList());
 
@@ -329,7 +329,7 @@ namespace MediaConch
         {
             QFileInfo f = QFileInfo(files[i]);
             on_file_selected(f.fileName(), f.absolutePath(), policy,
-                             display, verbosity, fixer, ret, err_str);
+                             display, verbosity, fixer, options, ret, err_str);
         }
         on_file_selected_end(err_str, ret);
 
@@ -338,21 +338,22 @@ namespace MediaConch
 
     QString WebCommonPage::on_file_online_selected(const QString& url, const QString& policy,
                                                    const QString& display, const QString& verbosity,
-                                                   bool)
+                                                   bool, const QStringList& options)
     {
         if (!url.length())
             return QString("{\"error\": \"No URL given.\"}");
 
         std::string err_str;
         QString ret;
-        on_file_selected(url, "", policy, display, verbosity, false, ret, err_str);
+        on_file_selected(url, "", policy, display, verbosity, false, options, ret, err_str);
         on_file_selected_end(err_str, ret);
 
         return ret;
     }
 
     QString WebCommonPage::on_file_repository_selected(const QString& policy, const QString& display,
-                                                       const QString& verbosity, bool fixer)
+                                                       const QString& verbosity, bool fixer,
+                                                       const QStringList& options)
     {
         QStringList dirname = file_selector.value("checkerRepository_directory", QStringList());
         if (dirname.empty())
@@ -367,7 +368,7 @@ namespace MediaConch
         std::string err_str;
         QString ret;
         for (int i = 0; i < list.size(); ++i)
-            on_file_selected(list[i].fileName(), list[i].absolutePath(), policy, display, verbosity, fixer, ret, err_str);
+            on_file_selected(list[i].fileName(), list[i].absolutePath(), policy, display, verbosity, fixer, options, ret, err_str);
         on_file_selected_end(err_str, ret);
 
         return ret;
@@ -426,7 +427,7 @@ namespace MediaConch
                 continue;
             }
 
-            ret += ",\"policyReport\":" + policy_is_valid(file_id);
+            ret += ",\"policyReport\":" + policy_is_valid(file_id, policy_ids[i].toInt());
 
             ret += "}";
         }
@@ -732,10 +733,16 @@ namespace MediaConch
             mainwindow->set_last_load_files_path(info.absolutePath().toUtf8().data());
         }
 
+        QStringList options;
+        if (checker_full_parse)
+        {
+            options << "file_parsespeed";
+            options << "1";
+        }
         QString res = on_file_upload_selected(QString().setNum(mainwindow->select_correct_policy()),
                                               QString().setNum(mainwindow->select_correct_display()),
                                               QString().setNum(mainwindow->select_correct_verbosity()),
-                                              false);
+                                              false, options);
 
         FileRegistered* fr = mainwindow->get_file_registered_from_file(tmp[0].toUtf8().data());
         if (!fr)
@@ -817,46 +824,27 @@ namespace MediaConch
         return QString().setNum(verbosity);
     }
 
-    QString WebCommonPage::policy_is_valid(long file_id)
+    QString WebCommonPage::policy_is_valid(long file_id, long policy_id)
     {
         //{"valid":false,"fileId":"fileId","error":null}
         std::string err;
         QString json = QString("{\"fileId\":\"%1\",").arg(file_id);
-        FileRegistered* fr = mainwindow->get_file_registered_from_id(file_id);
-        if (!fr)
-        {
-            json += QString("\"valid\":%1,\"error\":\"%2\"}")
-                .arg("false").arg("File not reachable");
-            return json;
-        }
-
-        if (!fr->analyzed)
-        {
-            json += QString("\"valid\":%1,\"error\":\"%2\"}")
-                .arg("false").arg("File not analyzed");
-            delete fr;
-            return json;
-        }
-
         bool policy_valid = false;
-        std::vector<MediaConchLib::Checker_ValidateRes*> res;
-        if (mainwindow->validate_policy(file_id, fr->policy, res, err) < 0)
+        if (mainwindow->update_policy_of_file_in_list(file_id, policy_id, err) < 0)
         {
             json += QString("\"valid\":false,\"error\":\"%2\"}")
                 .arg(QString().fromUtf8(err.c_str(), err.size()));
-            delete fr;
-            return json;
         }
 
-        if (res.size() == 1)
-            policy_valid = res[0]->valid;
-
-        for (size_t j = 0; j < res.size() ; ++j)
-            delete res[j];
-        res.clear();
+        FileRegistered* fr = mainwindow->get_file_registered_from_id(file_id);
+        if (!fr)
+        {
+            json += QString("\"valid\":false,\"error\":\"%2\"}")
+                .arg(QString().fromUtf8("File has been removed."));
+        }
 
         json += QString("\"valid\":%1,\"error\":%2}")
-            .arg(policy_valid ? "true" : "false").arg("null");
+            .arg(fr->policy_valid ? "true" : "false").arg("null");
 
         delete fr;
         return json;
@@ -889,17 +877,6 @@ namespace MediaConch
         return json;
     }
 
-    QString WebCommonPage::implementation_and_policy_is_valid(long file_id)
-    {
-        //{"implemReport":{"valid":true,"fileId":"fileId","error":null},"statusReport":{"valid":false,"fileId":"fileId","error":null}}
-        QString json = QString("{\"implemReport\":");
-        json += implementation_is_valid(file_id);
-        json += ",\"statusReport\":";
-        json += policy_is_valid(file_id);
-        json += "}";
-        return json;
-    }
-
     QString WebCommonPage::file_is_analyzed(const QStringList& ids)
     {
         QString json = QString("{\"status\":{");
@@ -946,11 +923,13 @@ namespace MediaConch
                         filename = "";
                     }
 
+                    QStringList opt;
+                    for (size_t k = 0; k < fr->options.size(); ++k)
+                        opt << QString().fromUtf8(fr->options[k].c_str(), fr->options[k].size());
                     if (mainwindow->add_attachment_to_list(QString().fromUtf8(filename.c_str(), filename.size()),
-                                                           fr->policy, fr->display, fr->verbosity, err) < 0)
-                    {
+                                                           fr->policy, fr->display, fr->verbosity, opt,
+                                                           err) < 0)
                         mainwindow->set_str_msg_to_status_bar(err);
-                    }
 
                     analyzed += QString("\"%1\":\"%2\"").arg(QString().number(fr->generated_id[x]))
                         .arg(QString().fromUtf8(filename.c_str(), filename.size()));
@@ -973,11 +952,6 @@ namespace MediaConch
         return json;
     }
 
-    void WebCommonPage::change_policy_for_file(long file_id, const QString& policy)
-    {
-        mainwindow->update_policy_of_file_in_list(file_id, policy);
-    }
-
     void WebCommonPage::add_sub_directory_files_to_list(const QDir dir, QFileInfoList& list)
     {
         QFileInfoList tmp = dir.entryInfoList(QDir::Files);
@@ -1211,10 +1185,12 @@ namespace MediaConch
 
         std::string error;
         QFileInfo f = QFileInfo(file);
+        QStringList options;
         if (mainwindow->add_file_to_list(f.fileName(), f.absolutePath(),
                                          QString().setNum(mainwindow->select_correct_policy()),
                                          QString().setNum(mainwindow->select_correct_display()),
-                                         QString().setNum(mainwindow->select_correct_verbosity()), false, true, error) < 0)
+                                         QString().setNum(mainwindow->select_correct_verbosity()), false, true,
+                                         options, error) < 0)
             return QString("{\"error\":\"%1\"").arg(QString().fromUtf8(error.c_str(), error.size()));
 
         return QString("{}");
@@ -1778,4 +1754,9 @@ namespace MediaConch
         settings.change_mco_token(token.toUtf8().data());
         return QString("{}");
     }
+
+    void WebCommonPage::set_full_parse(bool fp)
+    {
+        checker_full_parse = fp;
+    }
 }
