@@ -66,13 +66,15 @@ public:
     // Functions
     int                         add_file_to_list(const QString& file, const QString& path, const QString& policy,
                                                  const QString& display,
-                                                 const QString& verbosity, bool fixer, bool, std::string& err);
+                                                 const QString& verbosity, bool fixer, bool,
+                                                 const QStringList& options, std::string& err);
     int                         add_file_to_list(long id, std::string& err);
     int                         add_attachment_to_list(const QString& file, int policy, int display,
-                                                       int verbosity, std::string& err);
+                                                       int verbosity, const QStringList& options,
+                                                       std::string& err);
     void                        remove_file_to_list(long file_id);
     void                        remove_all_files_to_list();
-    void                        update_policy_of_file_in_list(long file_id, const QString& policy);
+    int                         update_policy_of_file_in_list(long file_id, long policy, std::string& error);
     int                         analyze_force_file_to_list(long id, std::string& err);
     void                        clear_file_list();
 
@@ -88,7 +90,8 @@ public:
     void                        set_widget_to_layout(QWidget* w);
     void                        remove_widget_from_layout(QWidget* w);
     int                         analyze(const std::vector<std::string>& files, bool with_fixer, bool force,
-                                        std::vector<long>& files_id, std::string& err);
+                                        const std::vector<std::string>& options, std::vector<long>& files_id,
+                                        std::string& err);
     int                         is_analyze_finished(const std::vector<std::string>& files,
                                                     std::vector<MediaConchLib::Checker_StatusRes>& res,std::string& err);
     int                         is_analyze_finished(const std::string& file, MediaConchLib::Checker_StatusRes& res, std::string& err);
@@ -105,6 +108,7 @@ public:
     int                         validate_policy(long file_id, size_t policy_id,
                                                 std::vector<MediaConchLib::Checker_ValidateRes*>& result, std::string& err);
 
+    void                        checker_stop(const std::vector<long>& ids);
     QString                     get_mediainfo_and_mediatrace_xml(long file_id, const std::string& display_name,
                                                                  const std::string& display_content, std::string& err);
     QString                     get_mediainfo_xml(long file_id, const std::string& display_name,
